@@ -7,14 +7,11 @@ Scan a list of folders and find all .afm files,
 then create rst2pdf-ready font-aliases.
 """
 
-from __future__ import unicode_literals
-
 import os
 import subprocess
 import sys
 from fnmatch import fnmatch
 
-import six
 from reportlab.lib.fonts import addMapping
 from reportlab.pdfbase import pdfmetrics
 from reportlab.pdfbase.ttfonts import (
@@ -139,7 +136,11 @@ def loadFonts():
                 continue
 
             # So now we have a font we know we can embed.
-            for n in (fontName.lower(), fullName.lower(), fullName.lower().replace("italic", "oblique")):
+            for n in (
+                fontName.lower(),
+                fullName.lower(),
+                fullName.lower().replace("italic", "oblique"),
+            ):
                 fonts[n] = (afm, pfbList[baseName], family)
 
             # And we can try to build/fill the family mapping
@@ -177,8 +178,6 @@ def findFont(fname):
 def findTTFont(fname):
     def get_family(query):
         data = make_string(subprocess.check_output(["fc-match", query]))
-        if six.PY2:
-            data = data.decode("UTF-8")
         for line in data.splitlines():
             line = line.strip()
             if not line:
@@ -223,10 +222,7 @@ def findTTFont(fname):
         # ctypes with EnumFontFamiliesEx
 
         def get_nt_fname(ftname):
-            if six.PY3:
-                import winreg as _w
-            else:
-                import _winreg as _w            
+            import winreg as _w
 
             fontkey = _w.OpenKey(
                 _w.HKEY_LOCAL_MACHINE,
